aboutsummaryrefslogtreecommitdiffstats
path: root/vespalib
diff options
context:
space:
mode:
authorTor Egge <Tor.Egge@broadpark.no>2020-05-04 11:37:01 +0200
committerTor Egge <Tor.Egge@broadpark.no>2020-05-04 11:37:01 +0200
commit12641f4383088dd087c1061739c5765393d2b129 (patch)
tree7ea647c0e6e646462feb50c46eb0a42d80b20515 /vespalib
parent44d195021c1742fdbddfcb6f9afac7fdd993a96a (diff)
Rename namespace search::btree to vespalib::btree.
Rename namespace search::datastore to vespalib::datastore.
Diffstat (limited to 'vespalib')
-rw-r--r--vespalib/src/tests/btree/btree_test.cpp6
-rw-r--r--vespalib/src/tests/btree/btreeaggregation_test.cpp6
-rw-r--r--vespalib/src/tests/btree/frozenbtree_test.cpp14
-rw-r--r--vespalib/src/tests/btree/iteratespeed.cpp4
-rw-r--r--vespalib/src/tests/datastore/array_store/array_store_test.cpp6
-rw-r--r--vespalib/src/tests/datastore/array_store_config/array_store_config_test.cpp2
-rw-r--r--vespalib/src/tests/datastore/buffer_type/buffer_type_test.cpp2
-rw-r--r--vespalib/src/tests/datastore/datastore/datastore_test.cpp2
-rw-r--r--vespalib/src/tests/datastore/unique_store/unique_store_test.cpp4
-rw-r--r--vespalib/src/tests/datastore/unique_store_dictionary/unique_store_dictionary_test.cpp4
-rw-r--r--vespalib/src/tests/datastore/unique_store_string_allocator/unique_store_string_allocator_test.cpp4
-rw-r--r--vespalib/src/vespa/vespalib/btree/btree.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btree.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btree_key_data.cpp4
-rw-r--r--vespalib/src/vespa/vespalib/btree/btree_key_data.h4
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeaggregator.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeaggregator.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeaggregator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreebuilder.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreebuilder.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreebuilder.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeinserter.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeinserter.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeinserter.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeiterator.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeiterator.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeiterator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreenode.cpp4
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreenode.h4
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreenode.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreenodeallocator.cpp4
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreenodeallocator.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreenodeallocator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreenodestore.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreenodestore.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreenodestore.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeremover.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeremover.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeremover.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeroot.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeroot.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreeroot.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreerootbase.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreerootbase.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreerootbase.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreestore.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreestore.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreestore.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/btree/btreetraits.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/minmaxaggrcalc.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/minmaxaggregated.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/noaggrcalc.h2
-rw-r--r--vespalib/src/vespa/vespalib/btree/noaggregated.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/allocator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/allocator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/array_store.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/array_store.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/array_store_config.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/array_store_config.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/atomic_entry_ref.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/buffer_type.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/buffer_type.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/bufferstate.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/bufferstate.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/datastore.cpp10
-rw-r--r--vespalib/src/vespa/vespalib/datastore/datastore.h4
-rw-r--r--vespalib/src/vespa/vespalib/datastore/datastore.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/datastorebase.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/datastorebase.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/entry_comparator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/entry_comparator_wrapper.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/entryref.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/entryref.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/entryref.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/free_list_allocator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/free_list_allocator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/handle.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/i_compactable.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/i_compaction_context.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/i_unique_store_dictionary.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/raw_allocator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/raw_allocator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_add_result.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_allocator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_allocator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_builder.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_builder.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_comparator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_entry.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_entry_base.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_remapper.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.cpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.hpp2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_string_comparator.h2
-rw-r--r--vespalib/src/vespa/vespalib/datastore/unique_store_value_filter.h2
-rw-r--r--vespalib/src/vespa/vespalib/test/btree/aggregated_printer.h4
-rw-r--r--vespalib/src/vespa/vespalib/test/btree/btree_printer.h4
-rw-r--r--vespalib/src/vespa/vespalib/test/btree/data_printer.h6
-rw-r--r--vespalib/src/vespa/vespalib/test/datastore/buffer_stats.h2
-rw-r--r--vespalib/src/vespa/vespalib/test/datastore/memstats.h2
109 files changed, 139 insertions, 139 deletions
diff --git a/vespalib/src/tests/btree/btree_test.cpp b/vespalib/src/tests/btree/btree_test.cpp
index 1b7eb4512ad..848c8a37125 100644
--- a/vespalib/src/tests/btree/btree_test.cpp
+++ b/vespalib/src/tests/btree/btree_test.cpp
@@ -21,9 +21,9 @@ LOG_SETUP("btree_test");
#include <vespa/vespalib/test/btree/btree_printer.h>
using vespalib::GenerationHandler;
-using search::datastore::EntryRef;
+using vespalib::datastore::EntryRef;
-namespace search::btree {
+namespace vespalib::btree {
namespace {
@@ -1521,4 +1521,4 @@ Test::Main()
}
-TEST_APPHOOK(search::btree::Test);
+TEST_APPHOOK(vespalib::btree::Test);
diff --git a/vespalib/src/tests/btree/btreeaggregation_test.cpp b/vespalib/src/tests/btree/btreeaggregation_test.cpp
index 2b4b37af171..da7f677bb8a 100644
--- a/vespalib/src/tests/btree/btreeaggregation_test.cpp
+++ b/vespalib/src/tests/btree/btreeaggregation_test.cpp
@@ -27,9 +27,9 @@
LOG_SETUP("btreeaggregation_test");
using vespalib::GenerationHandler;
-using search::datastore::EntryRef;
+using vespalib::datastore::EntryRef;
-namespace search::btree {
+namespace vespalib::btree {
namespace {
@@ -1234,4 +1234,4 @@ Test::Main()
}
-TEST_APPHOOK(search::btree::Test);
+TEST_APPHOOK(vespalib::btree::Test);
diff --git a/vespalib/src/tests/btree/frozenbtree_test.cpp b/vespalib/src/tests/btree/frozenbtree_test.cpp
index 9bf6f3773eb..e78c1b40dc6 100644
--- a/vespalib/src/tests/btree/frozenbtree_test.cpp
+++ b/vespalib/src/tests/btree/frozenbtree_test.cpp
@@ -13,14 +13,14 @@
#include <vespa/log/log.h>
LOG_SETUP("frozenbtree_test");
-using search::btree::BTreeRoot;
-using search::btree::BTreeNode;
-using search::btree::BTreeInternalNode;
-using search::btree::BTreeLeafNode;
-using search::btree::BTreeDefaultTraits;
+using vespalib::btree::BTreeRoot;
+using vespalib::btree::BTreeNode;
+using vespalib::btree::BTreeInternalNode;
+using vespalib::btree::BTreeLeafNode;
+using vespalib::btree::BTreeDefaultTraits;
using vespalib::GenerationHandler;
-namespace search {
+namespace vespalib {
class FrozenBTreeTest : public vespalib::TestApp
@@ -468,4 +468,4 @@ FrozenBTreeTest::Main()
}
-TEST_APPHOOK(search::FrozenBTreeTest);
+TEST_APPHOOK(vespalib::FrozenBTreeTest);
diff --git a/vespalib/src/tests/btree/iteratespeed.cpp b/vespalib/src/tests/btree/iteratespeed.cpp
index e20e9537f7f..e0664b1c588 100644
--- a/vespalib/src/tests/btree/iteratespeed.cpp
+++ b/vespalib/src/tests/btree/iteratespeed.cpp
@@ -21,7 +21,7 @@
#include <vespa/log/log.h>
LOG_SETUP("iteratespeed");
-namespace search::btree {
+namespace vespalib::btree {
enum class IterateMethod
{
@@ -204,6 +204,6 @@ IterateSpeed::Main()
}
-FASTOS_MAIN(search::btree::IterateSpeed);
+FASTOS_MAIN(vespalib::btree::IterateSpeed);
diff --git a/vespalib/src/tests/datastore/array_store/array_store_test.cpp b/vespalib/src/tests/datastore/array_store/array_store_test.cpp
index e74a277d964..ea7c746e58f 100644
--- a/vespalib/src/tests/datastore/array_store/array_store_test.cpp
+++ b/vespalib/src/tests/datastore/array_store/array_store_test.cpp
@@ -8,12 +8,12 @@
#include <vespa/vespalib/util/traits.h>
#include <vector>
-using namespace search::datastore;
+using namespace vespalib::datastore;
using vespalib::MemoryUsage;
using vespalib::ArrayRef;
using generation_t = vespalib::GenerationHandler::generation_t;
-using MemStats = search::datastore::test::MemStats;
-using BufferStats = search::datastore::test::BufferStats;
+using MemStats = vespalib::datastore::test::MemStats;
+using BufferStats = vespalib::datastore::test::BufferStats;
constexpr float ALLOC_GROW_FACTOR = 0.2;
diff --git a/vespalib/src/tests/datastore/array_store_config/array_store_config_test.cpp b/vespalib/src/tests/datastore/array_store_config/array_store_config_test.cpp
index 4779cf1aa70..e90149ed08f 100644
--- a/vespalib/src/tests/datastore/array_store_config/array_store_config_test.cpp
+++ b/vespalib/src/tests/datastore/array_store_config/array_store_config_test.cpp
@@ -4,7 +4,7 @@
#include <vespa/vespalib/datastore/entryref.h>
#include <vespa/vespalib/datastore/array_store_config.h>
-using namespace search::datastore;
+using namespace vespalib::datastore;
using AllocSpec = ArrayStoreConfig::AllocSpec;
constexpr float ALLOC_GROW_FACTOR = 0.2;
diff --git a/vespalib/src/tests/datastore/buffer_type/buffer_type_test.cpp b/vespalib/src/tests/datastore/buffer_type/buffer_type_test.cpp
index 3b748d1d4c7..abcf6d3b4e5 100644
--- a/vespalib/src/tests/datastore/buffer_type/buffer_type_test.cpp
+++ b/vespalib/src/tests/datastore/buffer_type/buffer_type_test.cpp
@@ -3,7 +3,7 @@
#include <vespa/vespalib/datastore/buffer_type.h>
#include <vespa/vespalib/testkit/testapp.h>
-using namespace search::datastore;
+using namespace vespalib::datastore;
using IntBufferType = BufferType<int>;
constexpr uint32_t ARRAYS_SIZE(4);
diff --git a/vespalib/src/tests/datastore/datastore/datastore_test.cpp b/vespalib/src/tests/datastore/datastore/datastore_test.cpp
index 0981280ac23..2429ad3853f 100644
--- a/vespalib/src/tests/datastore/datastore/datastore_test.cpp
+++ b/vespalib/src/tests/datastore/datastore/datastore_test.cpp
@@ -8,7 +8,7 @@
#include <vespa/log/log.h>
LOG_SETUP("datastore_test");
-namespace search::datastore {
+namespace vespalib::datastore {
using vespalib::alloc::MemoryAllocator;
diff --git a/vespalib/src/tests/datastore/unique_store/unique_store_test.cpp b/vespalib/src/tests/datastore/unique_store/unique_store_test.cpp
index e4631e28625..fad78ea30ae 100644
--- a/vespalib/src/tests/datastore/unique_store/unique_store_test.cpp
+++ b/vespalib/src/tests/datastore/unique_store/unique_store_test.cpp
@@ -12,10 +12,10 @@
#include <vespa/log/log.h>
LOG_SETUP("unique_store_test");
-using namespace search::datastore;
+using namespace vespalib::datastore;
using vespalib::ArrayRef;
using generation_t = vespalib::GenerationHandler::generation_t;
-using search::datastore::test::BufferStats;
+using vespalib::datastore::test::BufferStats;
template <typename UniqueStoreT>
struct TestBase : public ::testing::Test {
diff --git a/vespalib/src/tests/datastore/unique_store_dictionary/unique_store_dictionary_test.cpp b/vespalib/src/tests/datastore/unique_store_dictionary/unique_store_dictionary_test.cpp
index 1ec89aea69e..37a22108dc5 100644
--- a/vespalib/src/tests/datastore/unique_store_dictionary/unique_store_dictionary_test.cpp
+++ b/vespalib/src/tests/datastore/unique_store_dictionary/unique_store_dictionary_test.cpp
@@ -7,8 +7,8 @@
#include <vespa/log/log.h>
LOG_SETUP("unique_store_dictionary_test");
-using namespace search::datastore;
-using namespace search::datastore::uniquestore;
+using namespace vespalib::datastore;
+using namespace vespalib::datastore::uniquestore;
class Comparator : public EntryComparator {
private:
diff --git a/vespalib/src/tests/datastore/unique_store_string_allocator/unique_store_string_allocator_test.cpp b/vespalib/src/tests/datastore/unique_store_string_allocator/unique_store_string_allocator_test.cpp
index 048e1653ee4..94f96cdf707 100644
--- a/vespalib/src/tests/datastore/unique_store_string_allocator/unique_store_string_allocator_test.cpp
+++ b/vespalib/src/tests/datastore/unique_store_string_allocator/unique_store_string_allocator_test.cpp
@@ -7,10 +7,10 @@
#include <vespa/vespalib/util/traits.h>
#include <vector>
-using namespace search::datastore;
+using namespace vespalib::datastore;
using vespalib::MemoryUsage;
using generation_t = vespalib::GenerationHandler::generation_t;
-using BufferStats = search::datastore::test::BufferStats;
+using BufferStats = vespalib::datastore::test::BufferStats;
namespace {
diff --git a/vespalib/src/vespa/vespalib/btree/btree.h b/vespalib/src/vespa/vespalib/btree/btree.h
index 5d20964e169..c7e68901362 100644
--- a/vespalib/src/vespa/vespalib/btree/btree.h
+++ b/vespalib/src/vespa/vespalib/btree/btree.h
@@ -6,7 +6,7 @@
#include "noaggrcalc.h"
#include <vespa/vespalib/util/generationhandler.h>
-namespace search::btree {
+namespace vespalib::btree {
/**
* Class that wraps a btree root and an allocator and that provides the same API as
diff --git a/vespalib/src/vespa/vespalib/btree/btree.hpp b/vespalib/src/vespa/vespalib/btree/btree.hpp
index 7bba2e936f3..4bc96d58144 100644
--- a/vespalib/src/vespa/vespalib/btree/btree.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btree.hpp
@@ -4,7 +4,7 @@
#include "btree.h"
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT, typename DataT, typename AggrT, typename CompareT,
typename TraitsT, class AggrCalcT>
diff --git a/vespalib/src/vespa/vespalib/btree/btree_key_data.cpp b/vespalib/src/vespa/vespalib/btree/btree_key_data.cpp
index f30855e0589..b9d72c207f1 100644
--- a/vespalib/src/vespa/vespalib/btree/btree_key_data.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btree_key_data.cpp
@@ -2,11 +2,11 @@
#include "btree_key_data.h"
-namespace search::btree {
+namespace vespalib::btree {
BTreeNoLeafData BTreeNoLeafData::_instance;
template class BTreeKeyData<uint32_t, uint32_t>;
template class BTreeKeyData<uint32_t, int32_t>;
-} // namespace search::btree
+} // namespace vespalib::btree
diff --git a/vespalib/src/vespa/vespalib/btree/btree_key_data.h b/vespalib/src/vespa/vespalib/btree/btree_key_data.h
index 737651b755d..dc44faf00a9 100644
--- a/vespalib/src/vespa/vespalib/btree/btree_key_data.h
+++ b/vespalib/src/vespa/vespalib/btree/btree_key_data.h
@@ -4,7 +4,7 @@
#include <cstdint>
-namespace search::btree {
+namespace vespalib::btree {
/**
* Empty class to use as DataT template parameter for BTree classes to
@@ -82,4 +82,4 @@ public:
extern template class BTreeKeyData<uint32_t, uint32_t>;
extern template class BTreeKeyData<uint32_t, int32_t>;
-} // namespace search::btree
+} // namespace vespalib::btree
diff --git a/vespalib/src/vespa/vespalib/btree/btreeaggregator.cpp b/vespalib/src/vespa/vespalib/btree/btreeaggregator.cpp
index 2eb627192dc..2cad83577a0 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeaggregator.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeaggregator.cpp
@@ -3,7 +3,7 @@
#include "btreeaggregator.hpp"
#include "minmaxaggrcalc.h"
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeAggregator<uint32_t, uint32_t>;
template class BTreeAggregator<uint32_t, BTreeNoLeafData>;
diff --git a/vespalib/src/vespa/vespalib/btree/btreeaggregator.h b/vespalib/src/vespa/vespalib/btree/btreeaggregator.h
index 38c6f579f53..ece6370e5fa 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeaggregator.h
+++ b/vespalib/src/vespa/vespalib/btree/btreeaggregator.h
@@ -7,7 +7,7 @@
#include "btreetraits.h"
#include "noaggrcalc.h"
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT,
typename DataT,
diff --git a/vespalib/src/vespa/vespalib/btree/btreeaggregator.hpp b/vespalib/src/vespa/vespalib/btree/btreeaggregator.hpp
index 34dbfd3e899..2a04d7316b7 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeaggregator.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeaggregator.hpp
@@ -4,7 +4,7 @@
#include "btreeaggregator.h"
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT, typename DataT, typename AggrT,
size_t INTERNAL_SLOTS, size_t LEAF_SLOTS, class AggrCalcT>
diff --git a/vespalib/src/vespa/vespalib/btree/btreebuilder.cpp b/vespalib/src/vespa/vespalib/btree/btreebuilder.cpp
index 133c5d245c9..3201fb70eee 100644
--- a/vespalib/src/vespa/vespalib/btree/btreebuilder.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreebuilder.cpp
@@ -3,7 +3,7 @@
#include "btreenode.hpp"
#include "btreebuilder.hpp"
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeBuilder<uint32_t, uint32_t, NoAggregated,
BTreeDefaultTraits::INTERNAL_SLOTS,
diff --git a/vespalib/src/vespa/vespalib/btree/btreebuilder.h b/vespalib/src/vespa/vespalib/btree/btreebuilder.h
index 767f02d03ee..ecc67a6ad6c 100644
--- a/vespalib/src/vespa/vespalib/btree/btreebuilder.h
+++ b/vespalib/src/vespa/vespalib/btree/btreebuilder.h
@@ -9,7 +9,7 @@
#include "minmaxaggrcalc.h"
#include "btreeaggregator.h"
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT,
typename DataT,
diff --git a/vespalib/src/vespa/vespalib/btree/btreebuilder.hpp b/vespalib/src/vespa/vespalib/btree/btreebuilder.hpp
index 2cd7d80e06c..0374d46a7c3 100644
--- a/vespalib/src/vespa/vespalib/btree/btreebuilder.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreebuilder.hpp
@@ -4,7 +4,7 @@
#include "btreebuilder.h"
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT, typename DataT, typename AggrT,
size_t INTERNAL_SLOTS, size_t LEAF_SLOTS, class AggrCalcT>
diff --git a/vespalib/src/vespa/vespalib/btree/btreeinserter.cpp b/vespalib/src/vespa/vespalib/btree/btreeinserter.cpp
index c00d2342eed..7eb786d4ffe 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeinserter.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeinserter.cpp
@@ -6,7 +6,7 @@
#include "btreeinserter.hpp"
#include "btreenode.hpp"
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeInserter<uint32_t, uint32_t, NoAggregated>;
template class BTreeInserter<uint32_t, BTreeNoLeafData, NoAggregated>;
diff --git a/vespalib/src/vespa/vespalib/btree/btreeinserter.h b/vespalib/src/vespa/vespalib/btree/btreeinserter.h
index a66a7bc3f92..6fb859e488e 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeinserter.h
+++ b/vespalib/src/vespa/vespalib/btree/btreeinserter.h
@@ -10,7 +10,7 @@
#include "minmaxaggrcalc.h"
#include "btreeiterator.h"
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT,
typename DataT,
diff --git a/vespalib/src/vespa/vespalib/btree/btreeinserter.hpp b/vespalib/src/vespa/vespalib/btree/btreeinserter.hpp
index 5c6b02a5a46..434bb0db931 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeinserter.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeinserter.hpp
@@ -7,7 +7,7 @@
#include "btreeiterator.hpp"
#include <vespa/vespalib/stllike/asciistream.h>
-namespace search::btree {
+namespace vespalib::btree {
namespace {
diff --git a/vespalib/src/vespa/vespalib/btree/btreeiterator.cpp b/vespalib/src/vespa/vespalib/btree/btreeiterator.cpp
index 4dfc52304ac..1dc0c6056ba 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeiterator.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeiterator.cpp
@@ -3,7 +3,7 @@
#include "btreeiterator.hpp"
#include "btreenode.hpp"
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeIteratorBase<uint32_t, uint32_t, NoAggregated>;
template class BTreeIteratorBase<uint32_t, BTreeNoLeafData, NoAggregated>;
diff --git a/vespalib/src/vespa/vespalib/btree/btreeiterator.h b/vespalib/src/vespa/vespalib/btree/btreeiterator.h
index e3ad2147346..55ab37759ad 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeiterator.h
+++ b/vespalib/src/vespa/vespalib/btree/btreeiterator.h
@@ -7,7 +7,7 @@
#include "btreetraits.h"
#include <vespa/fastos/dynamiclibrary.h>
-namespace search::btree {
+namespace vespalib::btree {
template <typename, typename, typename, typename, typename, class>
class BTreeInserter;
diff --git a/vespalib/src/vespa/vespalib/btree/btreeiterator.hpp b/vespalib/src/vespa/vespalib/btree/btreeiterator.hpp
index 98a14943d36..82864bff057 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeiterator.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeiterator.hpp
@@ -7,7 +7,7 @@
#include "btreenode.hpp"
#include <vespa/vespalib/util/hdr_abort.h>
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT, typename DataT, typename AggrT,
uint32_t INTERNAL_SLOTS, uint32_t LEAF_SLOTS, uint32_t PATH_SIZE>
diff --git a/vespalib/src/vespa/vespalib/btree/btreenode.cpp b/vespalib/src/vespa/vespalib/btree/btreenode.cpp
index b3d7b60adb6..c723b31d706 100644
--- a/vespalib/src/vespa/vespalib/btree/btreenode.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreenode.cpp
@@ -2,7 +2,7 @@
#include "btreenode.hpp"
-namespace search::btree {
+namespace vespalib::btree {
NoAggregated BTreeNodeAggregatedWrap<NoAggregated>::_instance;
@@ -25,4 +25,4 @@ template class BTreeLeafNodeTemp<uint32_t, uint32_t, NoAggregated, 16>;
template class BTreeLeafNodeTemp<uint32_t, int32_t, MinMaxAggregated, 16>;
template class BTreeLeafNodeTemp<uint32_t, BTreeNoLeafData, NoAggregated, 16>;
-} // namespace search::btree
+} // namespace vespalib::btree
diff --git a/vespalib/src/vespa/vespalib/btree/btreenode.h b/vespalib/src/vespa/vespalib/btree/btreenode.h
index dd8fe09ec76..b34be33ccf5 100644
--- a/vespalib/src/vespa/vespalib/btree/btreenode.h
+++ b/vespalib/src/vespa/vespalib/btree/btreenode.h
@@ -11,7 +11,7 @@
#include <utility>
#include <cstddef>
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename, typename> class Allocator;
template <typename> class BufferType;
@@ -22,7 +22,7 @@ template <typename, typename ...> struct Assigner;
}
-namespace search::btree {
+namespace vespalib::btree {
template <typename, typename, typename, size_t, size_t> class BTreeNodeAllocator;
template <typename, typename, typename, size_t, size_t> class BTreeNodeStore;
diff --git a/vespalib/src/vespa/vespalib/btree/btreenode.hpp b/vespalib/src/vespa/vespalib/btree/btreenode.hpp
index 421e83a8440..b44315f480a 100644
--- a/vespalib/src/vespa/vespalib/btree/btreenode.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreenode.hpp
@@ -5,7 +5,7 @@
#include "btreenode.h"
#include <algorithm>
-namespace search::btree {
+namespace vespalib::btree {
namespace {
diff --git a/vespalib/src/vespa/vespalib/btree/btreenodeallocator.cpp b/vespalib/src/vespa/vespalib/btree/btreenodeallocator.cpp
index 1a05d68b04f..ef9634d4bad 100644
--- a/vespalib/src/vespa/vespalib/btree/btreenodeallocator.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreenodeallocator.cpp
@@ -3,9 +3,9 @@
#include "btreenodeallocator.hpp"
#include <vespa/vespalib/util/array.hpp>
-template class vespalib::Array<search::datastore::EntryRef>;
+template class vespalib::Array<vespalib::datastore::EntryRef>;
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeNodeAllocator<uint32_t, uint32_t, NoAggregated,
BTreeDefaultTraits::INTERNAL_SLOTS,
diff --git a/vespalib/src/vespa/vespalib/btree/btreenodeallocator.h b/vespalib/src/vespa/vespalib/btree/btreenodeallocator.h
index d2d2cf44a46..d5814eccbbc 100644
--- a/vespalib/src/vespa/vespalib/btree/btreenodeallocator.h
+++ b/vespalib/src/vespa/vespalib/btree/btreenodeallocator.h
@@ -10,7 +10,7 @@
#include <vespa/vespalib/util/memoryusage.h>
#include <vector>
-namespace search::btree {
+namespace vespalib::btree {
template <typename, typename, typename, size_t, size_t> class BTreeRootBase;
diff --git a/vespalib/src/vespa/vespalib/btree/btreenodeallocator.hpp b/vespalib/src/vespa/vespalib/btree/btreenodeallocator.hpp
index 197869a7c71..59a7d391563 100644
--- a/vespalib/src/vespa/vespalib/btree/btreenodeallocator.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreenodeallocator.hpp
@@ -8,7 +8,7 @@
#include <vespa/vespalib/util/array.hpp>
#include "btreenodestore.hpp"
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT, typename DataT, typename AggrT,
size_t INTERNAL_SLOTS, size_t LEAF_SLOTS>
diff --git a/vespalib/src/vespa/vespalib/btree/btreenodestore.cpp b/vespalib/src/vespa/vespalib/btree/btreenodestore.cpp
index 1e69dacddce..fd353fa6cd9 100644
--- a/vespalib/src/vespa/vespalib/btree/btreenodestore.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreenodestore.cpp
@@ -6,7 +6,7 @@
#include "btreenodeallocator.h"
#include <vespa/vespalib/datastore/datastore.h>
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeNodeStore<uint32_t, uint32_t, NoAggregated,
BTreeDefaultTraits::INTERNAL_SLOTS,
diff --git a/vespalib/src/vespa/vespalib/btree/btreenodestore.h b/vespalib/src/vespa/vespalib/btree/btreenodestore.h
index 43522629dbb..c887e436e83 100644
--- a/vespalib/src/vespa/vespalib/btree/btreenodestore.h
+++ b/vespalib/src/vespa/vespalib/btree/btreenodestore.h
@@ -6,7 +6,7 @@
#include "btreetraits.h"
#include <vespa/vespalib/datastore/datastore.h>
-namespace search::btree {
+namespace vespalib::btree {
class BTreeNodeReclaimer
{
diff --git a/vespalib/src/vespa/vespalib/btree/btreenodestore.hpp b/vespalib/src/vespa/vespalib/btree/btreenodestore.hpp
index ebbb57baa16..5a3846416cc 100644
--- a/vespalib/src/vespa/vespalib/btree/btreenodestore.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreenodestore.hpp
@@ -5,7 +5,7 @@
#include "btreenodestore.h"
#include <vespa/vespalib/datastore/datastore.hpp>
-namespace search::btree {
+namespace vespalib::btree {
template <typename EntryType>
void
diff --git a/vespalib/src/vespa/vespalib/btree/btreeremover.cpp b/vespalib/src/vespa/vespalib/btree/btreeremover.cpp
index f5ada77fed6..5a5b014a817 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeremover.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeremover.cpp
@@ -6,7 +6,7 @@
#include "btreeremover.hpp"
#include "btreenode.hpp"
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeRemover<uint32_t, uint32_t, NoAggregated>;
template class BTreeRemover<uint32_t, BTreeNoLeafData, NoAggregated>;
diff --git a/vespalib/src/vespa/vespalib/btree/btreeremover.h b/vespalib/src/vespa/vespalib/btree/btreeremover.h
index bbb825d6299..2a5068f9f6d 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeremover.h
+++ b/vespalib/src/vespa/vespalib/btree/btreeremover.h
@@ -10,7 +10,7 @@
#include "minmaxaggrcalc.h"
#include "btreeiterator.h"
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT,
typename DataT,
diff --git a/vespalib/src/vespa/vespalib/btree/btreeremover.hpp b/vespalib/src/vespa/vespalib/btree/btreeremover.hpp
index acb51b18b0c..72923fc5b7b 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeremover.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeremover.hpp
@@ -6,7 +6,7 @@
#include "btreerootbase.hpp"
#include <vespa/vespalib/stllike/asciistream.h>
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT, typename DataT, typename AggrT, size_t INTERNAL_SLOTS,
size_t LEAF_SLOTS, class AggrCalcT>
diff --git a/vespalib/src/vespa/vespalib/btree/btreeroot.cpp b/vespalib/src/vespa/vespalib/btree/btreeroot.cpp
index a576b6ce1e0..e1dd8c95456 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeroot.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeroot.cpp
@@ -6,7 +6,7 @@
#include "btreeroot.hpp"
#include "btreenode.hpp"
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeRootT<uint32_t, uint32_t, NoAggregated>;
template class BTreeRootT<uint32_t, BTreeNoLeafData, NoAggregated>;
diff --git a/vespalib/src/vespa/vespalib/btree/btreeroot.h b/vespalib/src/vespa/vespalib/btree/btreeroot.h
index 471f4273632..28efd00c40b 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeroot.h
+++ b/vespalib/src/vespa/vespalib/btree/btreeroot.h
@@ -9,7 +9,7 @@
#include "noaggrcalc.h"
#include "minmaxaggrcalc.h"
-namespace search::btree {
+namespace vespalib::btree {
template <typename, typename, typename, size_t, size_t>
class BTreeNodeAllocator;
diff --git a/vespalib/src/vespa/vespalib/btree/btreeroot.hpp b/vespalib/src/vespa/vespalib/btree/btreeroot.hpp
index 3893e0e0124..751ffbfca8e 100644
--- a/vespalib/src/vespa/vespalib/btree/btreeroot.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreeroot.hpp
@@ -10,7 +10,7 @@
#include "btreeaggregator.hpp"
#include <vespa/vespalib/stllike/asciistream.h>
-namespace search::btree {
+namespace vespalib::btree {
//----------------------- BTreeRoot ------------------------------------------//
diff --git a/vespalib/src/vespa/vespalib/btree/btreerootbase.cpp b/vespalib/src/vespa/vespalib/btree/btreerootbase.cpp
index 12394761bf9..35aa420378c 100644
--- a/vespalib/src/vespa/vespalib/btree/btreerootbase.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreerootbase.cpp
@@ -3,7 +3,7 @@
#include "btreerootbase.h"
#include "btreerootbase.hpp"
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeRootBase<uint32_t, uint32_t, NoAggregated,
BTreeDefaultTraits::INTERNAL_SLOTS,
diff --git a/vespalib/src/vespa/vespalib/btree/btreerootbase.h b/vespalib/src/vespa/vespalib/btree/btreerootbase.h
index ed4889214ca..1813e6de3d9 100644
--- a/vespalib/src/vespa/vespalib/btree/btreerootbase.h
+++ b/vespalib/src/vespa/vespalib/btree/btreerootbase.h
@@ -7,7 +7,7 @@
#include "btreenodeallocator.h"
#include <atomic>
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT,
typename DataT,
diff --git a/vespalib/src/vespa/vespalib/btree/btreerootbase.hpp b/vespalib/src/vespa/vespalib/btree/btreerootbase.hpp
index 0b4ef18aad9..97f84c0ccf3 100644
--- a/vespalib/src/vespa/vespalib/btree/btreerootbase.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreerootbase.hpp
@@ -4,7 +4,7 @@
#include "btreerootbase.h"
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT, typename DataT, typename AggrT,
size_t INTERNAL_SLOTS, size_t LEAF_SLOTS>
diff --git a/vespalib/src/vespa/vespalib/btree/btreestore.cpp b/vespalib/src/vespa/vespalib/btree/btreestore.cpp
index bead11295b3..9868721da88 100644
--- a/vespalib/src/vespa/vespalib/btree/btreestore.cpp
+++ b/vespalib/src/vespa/vespalib/btree/btreestore.cpp
@@ -4,7 +4,7 @@
#include "btreestore.hpp"
#include "btreeiterator.hpp"
-namespace search::btree {
+namespace vespalib::btree {
template class BTreeStore<uint32_t, uint32_t, NoAggregated, std::less<uint32_t>, BTreeDefaultTraits>;
template class BTreeStore<uint32_t, BTreeNoLeafData, NoAggregated, std::less<uint32_t>, BTreeDefaultTraits>;
diff --git a/vespalib/src/vespa/vespalib/btree/btreestore.h b/vespalib/src/vespa/vespalib/btree/btreestore.h
index 426baf80fa0..dfc4d86aca0 100644
--- a/vespalib/src/vespa/vespalib/btree/btreestore.h
+++ b/vespalib/src/vespa/vespalib/btree/btreestore.h
@@ -10,7 +10,7 @@
#include <vespa/vespalib/datastore/datastore.h>
#include <vespa/vespalib/datastore/handle.h>
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT,
typename DataT,
diff --git a/vespalib/src/vespa/vespalib/btree/btreestore.hpp b/vespalib/src/vespa/vespalib/btree/btreestore.hpp
index e6c96600b70..bb7238506ed 100644
--- a/vespalib/src/vespa/vespalib/btree/btreestore.hpp
+++ b/vespalib/src/vespa/vespalib/btree/btreestore.hpp
@@ -8,7 +8,7 @@
#include <vespa/vespalib/datastore/datastore.hpp>
#include <vespa/vespalib/util/optimized.h>
-namespace search::btree {
+namespace vespalib::btree {
template <typename KeyT, typename DataT, typename AggrT, typename CompareT,
typename TraitsT, typename AggrCalcT>
diff --git a/vespalib/src/vespa/vespalib/btree/btreetraits.h b/vespalib/src/vespa/vespalib/btree/btreetraits.h
index efa7cb4de34..6b64049899f 100644
--- a/vespalib/src/vespa/vespalib/btree/btreetraits.h
+++ b/vespalib/src/vespa/vespalib/btree/btreetraits.h
@@ -4,7 +4,7 @@
#include <cstddef>
-namespace search::btree {
+namespace vespalib::btree {
template <size_t LS, size_t IS, size_t PS, bool BS>
struct BTreeTraits {
diff --git a/vespalib/src/vespa/vespalib/btree/minmaxaggrcalc.h b/vespalib/src/vespa/vespalib/btree/minmaxaggrcalc.h
index 6ef809861b7..8ad03a8270c 100644
--- a/vespalib/src/vespa/vespalib/btree/minmaxaggrcalc.h
+++ b/vespalib/src/vespa/vespalib/btree/minmaxaggrcalc.h
@@ -4,7 +4,7 @@
#include "minmaxaggregated.h"
-namespace search::btree {
+namespace vespalib::btree {
class MinMaxAggrCalc
{
diff --git a/vespalib/src/vespa/vespalib/btree/minmaxaggregated.h b/vespalib/src/vespa/vespalib/btree/minmaxaggregated.h
index add570a6e6b..ec675f80325 100644
--- a/vespalib/src/vespa/vespalib/btree/minmaxaggregated.h
+++ b/vespalib/src/vespa/vespalib/btree/minmaxaggregated.h
@@ -5,7 +5,7 @@
#include <limits>
#include <cstdint>
-namespace search::btree {
+namespace vespalib::btree {
class MinMaxAggregated
{
diff --git a/vespalib/src/vespa/vespalib/btree/noaggrcalc.h b/vespalib/src/vespa/vespalib/btree/noaggrcalc.h
index 51958229430..ab11e9c689a 100644
--- a/vespalib/src/vespa/vespalib/btree/noaggrcalc.h
+++ b/vespalib/src/vespa/vespalib/btree/noaggrcalc.h
@@ -4,7 +4,7 @@
#include "noaggregated.h"
-namespace search::btree {
+namespace vespalib::btree {
class NoAggrCalc
{
diff --git a/vespalib/src/vespa/vespalib/btree/noaggregated.h b/vespalib/src/vespa/vespalib/btree/noaggregated.h
index e16465f5e0a..13793c6327f 100644
--- a/vespalib/src/vespa/vespalib/btree/noaggregated.h
+++ b/vespalib/src/vespa/vespalib/btree/noaggregated.h
@@ -2,7 +2,7 @@
#pragma once
-namespace search::btree {
+namespace vespalib::btree {
class NoAggregated
{
diff --git a/vespalib/src/vespa/vespalib/datastore/allocator.h b/vespalib/src/vespa/vespalib/datastore/allocator.h
index 8a522266c1a..30755a50716 100644
--- a/vespalib/src/vespa/vespalib/datastore/allocator.h
+++ b/vespalib/src/vespa/vespalib/datastore/allocator.h
@@ -7,7 +7,7 @@
#include "handle.h"
#include <vespa/vespalib/util/arrayref.h>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Allocator used to allocate entries of a specific type in an underlying data store.
diff --git a/vespalib/src/vespa/vespalib/datastore/allocator.hpp b/vespalib/src/vespa/vespalib/datastore/allocator.hpp
index fa22ba0c3ed..5f84d70e62f 100644
--- a/vespalib/src/vespa/vespalib/datastore/allocator.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/allocator.hpp
@@ -5,7 +5,7 @@
#include "allocator.h"
#include "bufferstate.h"
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename EntryT, typename RefT>
Allocator<EntryT, RefT>::Allocator(DataStoreBase &store, uint32_t typeId)
diff --git a/vespalib/src/vespa/vespalib/datastore/array_store.h b/vespalib/src/vespa/vespalib/datastore/array_store.h
index 4c289c04564..05af192c77f 100644
--- a/vespalib/src/vespa/vespalib/datastore/array_store.h
+++ b/vespalib/src/vespa/vespalib/datastore/array_store.h
@@ -10,7 +10,7 @@
#include "i_compaction_context.h"
#include <vespa/vespalib/util/array.h>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Datastore for storing arrays of type EntryT that is accessed via a 32-bit EntryRef.
diff --git a/vespalib/src/vespa/vespalib/datastore/array_store.hpp b/vespalib/src/vespa/vespalib/datastore/array_store.hpp
index 56aa2d5e2c3..d43245db1de 100644
--- a/vespalib/src/vespa/vespalib/datastore/array_store.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/array_store.hpp
@@ -7,7 +7,7 @@
#include <atomic>
#include <algorithm>
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename EntryT, typename RefT>
ArrayStore<EntryT, RefT>::LargeArrayType::LargeArrayType(const AllocSpec &spec)
diff --git a/vespalib/src/vespa/vespalib/datastore/array_store_config.cpp b/vespalib/src/vespa/vespalib/datastore/array_store_config.cpp
index ef3d40b98b2..21d7ed9f114 100644
--- a/vespalib/src/vespa/vespalib/datastore/array_store_config.cpp
+++ b/vespalib/src/vespa/vespalib/datastore/array_store_config.cpp
@@ -3,7 +3,7 @@
#include "array_store_config.h"
#include <cassert>
-namespace search::datastore {
+namespace vespalib::datastore {
ArrayStoreConfig::ArrayStoreConfig(size_t maxSmallArraySize, const AllocSpec &defaultSpec)
: _allocSpecs(),
diff --git a/vespalib/src/vespa/vespalib/datastore/array_store_config.h b/vespalib/src/vespa/vespalib/datastore/array_store_config.h
index fba60f76b6c..fbe70eb2553 100644
--- a/vespalib/src/vespa/vespalib/datastore/array_store_config.h
+++ b/vespalib/src/vespa/vespalib/datastore/array_store_config.h
@@ -5,7 +5,7 @@
#include <cstddef>
#include <vector>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Config specifying layout and buffer allocation strategy for an array store.
diff --git a/vespalib/src/vespa/vespalib/datastore/atomic_entry_ref.h b/vespalib/src/vespa/vespalib/datastore/atomic_entry_ref.h
index 154c9669550..ed45723b6ef 100644
--- a/vespalib/src/vespa/vespalib/datastore/atomic_entry_ref.h
+++ b/vespalib/src/vespa/vespalib/datastore/atomic_entry_ref.h
@@ -5,7 +5,7 @@
#include "entryref.h"
#include <atomic>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* A wrapper for std::atomic of type EntryRef that supports copy and move constructors and assignment operator,
diff --git a/vespalib/src/vespa/vespalib/datastore/buffer_type.cpp b/vespalib/src/vespa/vespalib/datastore/buffer_type.cpp
index e7b878df3a1..ebc1dc5a5b7 100644
--- a/vespalib/src/vespa/vespalib/datastore/buffer_type.cpp
+++ b/vespalib/src/vespa/vespalib/datastore/buffer_type.cpp
@@ -4,7 +4,7 @@
#include <algorithm>
#include <cassert>
-namespace search::datastore {
+namespace vespalib::datastore {
namespace {
diff --git a/vespalib/src/vespa/vespalib/datastore/buffer_type.h b/vespalib/src/vespa/vespalib/datastore/buffer_type.h
index eb432e6dc76..dbd399a1bcd 100644
--- a/vespalib/src/vespa/vespalib/datastore/buffer_type.h
+++ b/vespalib/src/vespa/vespalib/datastore/buffer_type.h
@@ -5,7 +5,7 @@
#include <cstdint>
#include <cstddef>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Abstract class used to manage allocation and de-allocation of a specific data type in underlying memory buffers in a data store.
diff --git a/vespalib/src/vespa/vespalib/datastore/bufferstate.cpp b/vespalib/src/vespa/vespalib/datastore/bufferstate.cpp
index 638117c8c60..acebe8d0db6 100644
--- a/vespalib/src/vespa/vespalib/datastore/bufferstate.cpp
+++ b/vespalib/src/vespa/vespalib/datastore/bufferstate.cpp
@@ -6,7 +6,7 @@
using vespalib::alloc::Alloc;
using vespalib::alloc::MemoryAllocator;
-namespace search::datastore {
+namespace vespalib::datastore {
BufferState::FreeListList::~FreeListList()
{
diff --git a/vespalib/src/vespa/vespalib/datastore/bufferstate.h b/vespalib/src/vespa/vespalib/datastore/bufferstate.h
index 3fe32bb59a1..814b4fe95f7 100644
--- a/vespalib/src/vespa/vespalib/datastore/bufferstate.h
+++ b/vespalib/src/vespa/vespalib/datastore/bufferstate.h
@@ -8,7 +8,7 @@
#include <vespa/vespalib/util/alloc.h>
#include <vespa/vespalib/util/array.h>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Represents a memory allocated buffer (used in a data store) with its state.
diff --git a/vespalib/src/vespa/vespalib/datastore/datastore.cpp b/vespalib/src/vespa/vespalib/datastore/datastore.cpp
index 308dc750113..1b2b010c4ed 100644
--- a/vespalib/src/vespa/vespalib/datastore/datastore.cpp
+++ b/vespalib/src/vespa/vespalib/datastore/datastore.cpp
@@ -5,13 +5,13 @@
#include <vespa/vespalib/util/array.hpp>
#include <vespa/vespalib/util/rcuvector.hpp>
-namespace search::datastore {
+namespace vespalib::datastore {
template class DataStoreT<EntryRefT<22> >;
}
-template void vespalib::Array<search::datastore::DataStoreBase::ElemHold1ListElem>::increase(size_t);
-template class vespalib::RcuVector<search::datastore::EntryRef>;
-template class vespalib::RcuVectorBase<search::datastore::EntryRef>;
-//template void vespalib::RcuVectorBase<search::datastore::EntryRef>::expandAndInsert(const search::datastore::EntryRef &);
+template void vespalib::Array<vespalib::datastore::DataStoreBase::ElemHold1ListElem>::increase(size_t);
+template class vespalib::RcuVector<vespalib::datastore::EntryRef>;
+template class vespalib::RcuVectorBase<vespalib::datastore::EntryRef>;
+//template void vespalib::RcuVectorBase<vespalib::datastore::EntryRef>::expandAndInsert(const vespalib::datastore::EntryRef &);
diff --git a/vespalib/src/vespa/vespalib/datastore/datastore.h b/vespalib/src/vespa/vespalib/datastore/datastore.h
index 6d7376f1b0c..193869a5591 100644
--- a/vespalib/src/vespa/vespalib/datastore/datastore.h
+++ b/vespalib/src/vespa/vespalib/datastore/datastore.h
@@ -8,7 +8,7 @@
#include "free_list_raw_allocator.h"
#include "raw_allocator.h"
-namespace search::btree {
+namespace vespalib::btree {
template<typename EntryType>
struct DefaultReclaimer {
@@ -19,7 +19,7 @@ struct DefaultReclaimer {
}
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Concrete data store using the given EntryRef type to reference stored data.
diff --git a/vespalib/src/vespa/vespalib/datastore/datastore.hpp b/vespalib/src/vespa/vespalib/datastore/datastore.hpp
index 0e4d1bbe652..6549425b022 100644
--- a/vespalib/src/vespa/vespalib/datastore/datastore.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/datastore.hpp
@@ -9,7 +9,7 @@
#include "raw_allocator.hpp"
#include <vespa/vespalib/util/array.hpp>
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename RefT>
DataStoreT<RefT>::DataStoreT()
diff --git a/vespalib/src/vespa/vespalib/datastore/datastorebase.cpp b/vespalib/src/vespa/vespalib/datastore/datastorebase.cpp
index 2f9dc1dc84a..4e68b10d76a 100644
--- a/vespalib/src/vespa/vespalib/datastore/datastorebase.cpp
+++ b/vespalib/src/vespa/vespalib/datastore/datastorebase.cpp
@@ -9,7 +9,7 @@ LOG_SETUP(".searchlib.datastore.datastorebase");
using vespalib::GenerationHeldBase;
-namespace search::datastore {
+namespace vespalib::datastore {
namespace {
diff --git a/vespalib/src/vespa/vespalib/datastore/datastorebase.h b/vespalib/src/vespa/vespalib/datastore/datastorebase.h
index 22b1a53f0ab..a08a210635c 100644
--- a/vespalib/src/vespa/vespalib/datastore/datastorebase.h
+++ b/vespalib/src/vespa/vespalib/datastore/datastorebase.h
@@ -10,7 +10,7 @@
#include <deque>
#include <atomic>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Abstract class used to store data of potential different types in underlying memory buffers.
diff --git a/vespalib/src/vespa/vespalib/datastore/entry_comparator.h b/vespalib/src/vespa/vespalib/datastore/entry_comparator.h
index 09b850a4746..d0b5b307a9e 100644
--- a/vespalib/src/vespa/vespalib/datastore/entry_comparator.h
+++ b/vespalib/src/vespa/vespalib/datastore/entry_comparator.h
@@ -4,7 +4,7 @@
#include "entryref.h"
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Less-than comparator for two entries based on entry refs.
diff --git a/vespalib/src/vespa/vespalib/datastore/entry_comparator_wrapper.h b/vespalib/src/vespa/vespalib/datastore/entry_comparator_wrapper.h
index c84f81f9d6e..199d074b453 100644
--- a/vespalib/src/vespa/vespalib/datastore/entry_comparator_wrapper.h
+++ b/vespalib/src/vespa/vespalib/datastore/entry_comparator_wrapper.h
@@ -4,7 +4,7 @@
#include "entry_comparator.h"
-namespace search::datastore {
+namespace vespalib::datastore {
/*
* Copyable comparator wrapper.
diff --git a/vespalib/src/vespa/vespalib/datastore/entryref.cpp b/vespalib/src/vespa/vespalib/datastore/entryref.cpp
index e90afb877bd..0551e617283 100644
--- a/vespalib/src/vespa/vespalib/datastore/entryref.cpp
+++ b/vespalib/src/vespa/vespalib/datastore/entryref.cpp
@@ -3,7 +3,7 @@
#include "entryref.hpp"
#include <vespa/vespalib/stllike/asciistream.h>
-namespace search::datastore {
+namespace vespalib::datastore {
template EntryRefT<24u, 8u>::EntryRefT(size_t, uint32_t);
template EntryRefT<31u, 1u>::EntryRefT(size_t, uint32_t);
diff --git a/vespalib/src/vespa/vespalib/datastore/entryref.h b/vespalib/src/vespa/vespalib/datastore/entryref.h
index d49b1ab9071..51a4e0699fc 100644
--- a/vespalib/src/vespa/vespalib/datastore/entryref.h
+++ b/vespalib/src/vespa/vespalib/datastore/entryref.h
@@ -7,7 +7,7 @@
namespace vespalib { class asciistream; }
-namespace search::datastore {
+namespace vespalib::datastore {
class EntryRef {
protected:
diff --git a/vespalib/src/vespa/vespalib/datastore/entryref.hpp b/vespalib/src/vespa/vespalib/datastore/entryref.hpp
index b7aafb30fdd..56ebe62dfab 100644
--- a/vespalib/src/vespa/vespalib/datastore/entryref.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/entryref.hpp
@@ -5,7 +5,7 @@
#include "entryref.h"
#include <vespa/vespalib/util/assert.h>
-namespace search::datastore {
+namespace vespalib::datastore {
template <uint32_t OffsetBits, uint32_t BufferBits>
EntryRefT<OffsetBits, BufferBits>::EntryRefT(size_t offset_, uint32_t bufferId_) :
diff --git a/vespalib/src/vespa/vespalib/datastore/free_list_allocator.h b/vespalib/src/vespa/vespalib/datastore/free_list_allocator.h
index a23cb71b90c..ae8b1bb1c72 100644
--- a/vespalib/src/vespa/vespalib/datastore/free_list_allocator.h
+++ b/vespalib/src/vespa/vespalib/datastore/free_list_allocator.h
@@ -4,7 +4,7 @@
#include "allocator.h"
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Allocator used to allocate entries of a specific type in an underlying data store
diff --git a/vespalib/src/vespa/vespalib/datastore/free_list_allocator.hpp b/vespalib/src/vespa/vespalib/datastore/free_list_allocator.hpp
index 402fbe26725..32ae33a56c0 100644
--- a/vespalib/src/vespa/vespalib/datastore/free_list_allocator.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/free_list_allocator.hpp
@@ -5,7 +5,7 @@
#include "free_list_allocator.h"
#include "bufferstate.h"
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename EntryT, typename RefT, typename ReclaimerT>
FreeListAllocator<EntryT, RefT, ReclaimerT>::FreeListAllocator(DataStoreBase &store, uint32_t typeId)
diff --git a/vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.h b/vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.h
index 514eecc25a8..b6eec5b9742 100644
--- a/vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.h
+++ b/vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.h
@@ -4,7 +4,7 @@
#include "raw_allocator.h"
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Allocator used to allocate raw buffers (EntryT *) in an underlying data store
diff --git a/vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.hpp b/vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.hpp
index 0e97d6a3c33..5679f3a849b 100644
--- a/vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/free_list_raw_allocator.hpp
@@ -4,7 +4,7 @@
#include "free_list_raw_allocator.h"
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename EntryT, typename RefT>
FreeListRawAllocator<EntryT, RefT>::FreeListRawAllocator(DataStoreBase &store, uint32_t typeId)
diff --git a/vespalib/src/vespa/vespalib/datastore/handle.h b/vespalib/src/vespa/vespalib/datastore/handle.h
index 49eb4843816..46908325ad9 100644
--- a/vespalib/src/vespa/vespalib/datastore/handle.h
+++ b/vespalib/src/vespa/vespalib/datastore/handle.h
@@ -4,7 +4,7 @@
#include "entryref.h"
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Handle to data allocated in a data store and a EntryRef used for read-only access to data later.
diff --git a/vespalib/src/vespa/vespalib/datastore/i_compactable.h b/vespalib/src/vespa/vespalib/datastore/i_compactable.h
index 599b2adfa20..d676acfb5a7 100644
--- a/vespalib/src/vespa/vespalib/datastore/i_compactable.h
+++ b/vespalib/src/vespa/vespalib/datastore/i_compactable.h
@@ -2,7 +2,7 @@
#pragma once
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Interface for moving an entry as part of compaction of data in old
diff --git a/vespalib/src/vespa/vespalib/datastore/i_compaction_context.h b/vespalib/src/vespa/vespalib/datastore/i_compaction_context.h
index aa537968f1c..72b473adf4a 100644
--- a/vespalib/src/vespa/vespalib/datastore/i_compaction_context.h
+++ b/vespalib/src/vespa/vespalib/datastore/i_compaction_context.h
@@ -4,7 +4,7 @@
#include <vespa/vespalib/util/array.h>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* A compaction context is used when performing a compaction of data buffers in a data store.
diff --git a/vespalib/src/vespa/vespalib/datastore/i_unique_store_dictionary.h b/vespalib/src/vespa/vespalib/datastore/i_unique_store_dictionary.h
index 9604d1d5339..6b9a4f7201e 100644
--- a/vespalib/src/vespa/vespalib/datastore/i_unique_store_dictionary.h
+++ b/vespalib/src/vespa/vespalib/datastore/i_unique_store_dictionary.h
@@ -8,7 +8,7 @@
#include <vespa/vespalib/util/memoryusage.h>
#include <functional>
-namespace search::datastore {
+namespace vespalib::datastore {
class EntryComparator;
struct ICompactable;
diff --git a/vespalib/src/vespa/vespalib/datastore/raw_allocator.h b/vespalib/src/vespa/vespalib/datastore/raw_allocator.h
index b7c00f75580..e09639f08e9 100644
--- a/vespalib/src/vespa/vespalib/datastore/raw_allocator.h
+++ b/vespalib/src/vespa/vespalib/datastore/raw_allocator.h
@@ -6,7 +6,7 @@
#include "entryref.h"
#include "handle.h"
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Allocator used to allocate raw buffers (EntryT *) in an underlying data store
diff --git a/vespalib/src/vespa/vespalib/datastore/raw_allocator.hpp b/vespalib/src/vespa/vespalib/datastore/raw_allocator.hpp
index 9b86305a634..43a793d69f7 100644
--- a/vespalib/src/vespa/vespalib/datastore/raw_allocator.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/raw_allocator.hpp
@@ -5,7 +5,7 @@
#include "raw_allocator.h"
#include "bufferstate.h"
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename EntryT, typename RefT>
RawAllocator<EntryT, RefT>::RawAllocator(DataStoreBase &store, uint32_t typeId)
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store.h b/vespalib/src/vespa/vespalib/datastore/unique_store.h
index 5758c7e3481..a47792de402 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store.h
@@ -13,7 +13,7 @@
#include "unique_store_comparator.h"
#include "unique_store_entry.h"
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename Allocator>
class UniqueStoreBuilder;
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store.hpp b/vespalib/src/vespa/vespalib/datastore/unique_store.hpp
index 956d4c16d40..8b9525f5ad7 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store.hpp
@@ -13,7 +13,7 @@
#include <atomic>
#include <algorithm>
-namespace search::datastore {
+namespace vespalib::datastore {
namespace uniquestore {
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_add_result.h b/vespalib/src/vespa/vespalib/datastore/unique_store_add_result.h
index eee5dbb535f..cc5f57e11a1 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_add_result.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_add_result.h
@@ -5,7 +5,7 @@
#include "entryref.h"
-namespace search::datastore {
+namespace vespalib::datastore {
/*
* Representation of result of adding a value to unique store.
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_allocator.h b/vespalib/src/vespa/vespalib/datastore/unique_store_allocator.h
index a4443742e33..8f81fec6554 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_allocator.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_allocator.h
@@ -8,7 +8,7 @@
#include "unique_store_entry.h"
#include "i_compactable.h"
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Allocator for unique values of type EntryT that is accessed via a
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_allocator.hpp b/vespalib/src/vespa/vespalib/datastore/unique_store_allocator.hpp
index 83772224713..b54c54e9bcc 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_allocator.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_allocator.hpp
@@ -6,7 +6,7 @@
#include "unique_store_value_filter.h"
#include "datastore.hpp"
-namespace search::datastore {
+namespace vespalib::datastore {
constexpr size_t NUM_ARRAYS_FOR_NEW_UNIQUESTORE_BUFFER = 1024u;
constexpr float ALLOC_GROW_FACTOR = 0.2;
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_builder.h b/vespalib/src/vespa/vespalib/datastore/unique_store_builder.h
index c0a44855063..f2be4e1237b 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_builder.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_builder.h
@@ -4,7 +4,7 @@
#include "unique_store_allocator.h"
-namespace search::datastore {
+namespace vespalib::datastore {
class IUniqueStoreDictionary;
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_builder.hpp b/vespalib/src/vespa/vespalib/datastore/unique_store_builder.hpp
index 7ea61f4e0ea..0925702ddcb 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_builder.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_builder.hpp
@@ -6,7 +6,7 @@
#include "i_unique_store_dictionary.h"
#include "datastore.hpp"
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename Allocator>
UniqueStoreBuilder<Allocator>::UniqueStoreBuilder(Allocator& allocator, IUniqueStoreDictionary& dict, uint32_t uniqueValuesHint)
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_comparator.h b/vespalib/src/vespa/vespalib/datastore/unique_store_comparator.h
index 4fcef84e3f7..3226c4563cc 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_comparator.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_comparator.h
@@ -7,7 +7,7 @@
#include "datastore.h"
#include <cmath>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Helper class for comparing elements in unique store.
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.h b/vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.h
index 69fbc332485..4ec98dc2100 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.h
@@ -5,7 +5,7 @@
#pragma once
-namespace search::datastore {
+namespace vespalib::datastore {
class EntryComparatorWrapper;
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.hpp b/vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.hpp
index b1189a1b37b..bce11591970 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_dictionary.hpp
@@ -14,7 +14,7 @@
#include <vespa/vespalib/btree/btreenodeallocator.hpp>
#include <vespa/vespalib/btree/btreeroot.hpp>
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename DictionaryT, typename ParentT>
UniqueStoreDictionary<DictionaryT, ParentT>::
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_entry.h b/vespalib/src/vespa/vespalib/datastore/unique_store_entry.h
index 87c8e860244..78514fe0571 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_entry.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_entry.h
@@ -6,7 +6,7 @@
#include <cassert>
#include <utility>
-namespace search::datastore {
+namespace vespalib::datastore {
template<typename EntryType>
struct UniqueStoreEntryReclaimer {
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_entry_base.h b/vespalib/src/vespa/vespalib/datastore/unique_store_entry_base.h
index 79ebae9389f..ff695c80cba 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_entry_base.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_entry_base.h
@@ -7,7 +7,7 @@
#include <cassert>
#include <limits>
-namespace search::datastore {
+namespace vespalib::datastore {
/*
* Class containing common metadata for entries in unique store.
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.h b/vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.h
index 5341647815e..db545451a30 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.h
@@ -4,7 +4,7 @@
#include "i_unique_store_dictionary.h"
-namespace search::datastore {
+namespace vespalib::datastore {
class DataStoreBase;
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.hpp b/vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.hpp
index 48489e9edd5..d779b2f2bd3 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_enumerator.hpp
@@ -6,7 +6,7 @@
#include <vespa/vespalib/datastore/bufferstate.h>
#include <vespa/vespalib/datastore/datastorebase.h>
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename RefT>
UniqueStoreEnumerator<RefT>::UniqueStoreEnumerator(const IUniqueStoreDictionary &dict, const DataStoreBase &store)
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_remapper.h b/vespalib/src/vespa/vespalib/datastore/unique_store_remapper.h
index 13a732e6524..1fa74f59f1a 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_remapper.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_remapper.h
@@ -5,7 +5,7 @@
#include "entryref.h"
#include <vector>
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Remapper for related UniqueStore class, used for adjusting
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.cpp b/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.cpp
index d7b79c439ef..4f8b1b878f0 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.cpp
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.cpp
@@ -2,7 +2,7 @@
#include "unique_store_string_allocator.hpp"
-namespace search::datastore {
+namespace vespalib::datastore {
namespace {
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.h b/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.h
index f72b9c6119c..7ad4384bece 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.h
@@ -10,7 +10,7 @@
#include <cassert>
#include <string>
-namespace search::datastore {
+namespace vespalib::datastore {
namespace string_allocator {
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.hpp b/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.hpp
index 2b2af70439a..2fe12238342 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.hpp
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_string_allocator.hpp
@@ -5,7 +5,7 @@
#include "unique_store_string_allocator.h"
#include "datastore.hpp"
-namespace search::datastore {
+namespace vespalib::datastore {
template <typename RefT>
UniqueStoreStringAllocator<RefT>::UniqueStoreStringAllocator()
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_string_comparator.h b/vespalib/src/vespa/vespalib/datastore/unique_store_string_comparator.h
index 80e7a501cfa..140e38dbef1 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_string_comparator.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_string_comparator.h
@@ -5,7 +5,7 @@
#include "entry_comparator.h"
#include "unique_store_string_allocator.h"
-namespace search::datastore {
+namespace vespalib::datastore {
/**
* Compare two strings based on entry refs.
diff --git a/vespalib/src/vespa/vespalib/datastore/unique_store_value_filter.h b/vespalib/src/vespa/vespalib/datastore/unique_store_value_filter.h
index 3694936c550..58409357186 100644
--- a/vespalib/src/vespa/vespalib/datastore/unique_store_value_filter.h
+++ b/vespalib/src/vespa/vespalib/datastore/unique_store_value_filter.h
@@ -2,7 +2,7 @@
#pragma once
-namespace search::datastore {
+namespace vespalib::datastore {
/*
* Helper class for normalizing values inserted into unique store.
diff --git a/vespalib/src/vespa/vespalib/test/btree/aggregated_printer.h b/vespalib/src/vespa/vespalib/test/btree/aggregated_printer.h
index 18544ef9007..0be569491b1 100644
--- a/vespalib/src/vespa/vespalib/test/btree/aggregated_printer.h
+++ b/vespalib/src/vespa/vespalib/test/btree/aggregated_printer.h
@@ -5,7 +5,7 @@
#include <vespa/vespalib/btree/noaggregated.h>
#include <vespa/vespalib/btree/minmaxaggregated.h>
-namespace search::btree::test {
+namespace vespalib::btree::test {
template <typename ostream, typename Aggregated>
void printAggregated(ostream &os, const Aggregated &aggr);
@@ -23,4 +23,4 @@ void printAggregated(ostream &os, const MinMaxAggregated &aggr)
os << "[min=" << aggr.getMin() << ",max=" << aggr.getMax() << "]";
}
-} // namespace search::btree::test
+} // namespace vespalib::btree::test
diff --git a/vespalib/src/vespa/vespalib/test/btree/btree_printer.h b/vespalib/src/vespa/vespalib/test/btree/btree_printer.h
index b5d0e6b5ccb..cd29f373bda 100644
--- a/vespalib/src/vespa/vespalib/test/btree/btree_printer.h
+++ b/vespalib/src/vespa/vespalib/test/btree/btree_printer.h
@@ -6,7 +6,7 @@
#include "aggregated_printer.h"
#include <vespa/vespalib/btree/btreenodeallocator.h>
-namespace search::btree::test {
+namespace vespalib::btree::test {
template <typename ostream, typename NodeAllocator>
class BTreePrinter
@@ -100,4 +100,4 @@ public:
}
};
-} // namespace search::btree::test
+} // namespace vespalib::btree::test
diff --git a/vespalib/src/vespa/vespalib/test/datastore/buffer_stats.h b/vespalib/src/vespa/vespalib/test/datastore/buffer_stats.h
index bdf49562c33..2484c50b33b 100644
--- a/vespalib/src/vespa/vespalib/test/datastore/buffer_stats.h
+++ b/vespalib/src/vespa/vespalib/test/datastore/buffer_stats.h
@@ -5,7 +5,7 @@
#include <cassert>
#include <cstddef>
-namespace search::datastore::test {
+namespace vespalib::datastore::test {
/*
* Class representing expected buffer stats in unit tests.
diff --git a/vespalib/src/vespa/vespalib/test/datastore/memstats.h b/vespalib/src/vespa/vespalib/test/datastore/memstats.h
index 6f3c8b86482..04e7e6d9090 100644
--- a/vespalib/src/vespa/vespalib/test/datastore/memstats.h
+++ b/vespalib/src/vespa/vespalib/test/datastore/memstats.h
@@ -5,7 +5,7 @@
#include <vespa/vespalib/util/memoryusage.h>
#include <cassert>
-namespace search::datastore::test {
+namespace vespalib::datastore::test {
/*
* Class representing expected memory stats in unit tests.
diff --git a/vespalib/src/vespa/vespalib/test/btree/data_printer.h b/vespalib/src/vespa/vespalib/test/btree/data_printer.h
index 26b77da0db7..c87b3aad949 100644
--- a/vespalib/src/vespa/vespalib/test/btree/data_printer.h
+++ b/vespalib/src/vespa/vespalib/test/btree/data_printer.h
@@ -2,7 +2,7 @@
#pragma once
-namespace search::btree {
+namespace vespalib::btree {
class BtreeNoLeafData;
@@ -24,5 +24,5 @@ void printData(ostream &os, const BTreeNoLeafData &data)
(void) data;
}
-} // namespace search::btree::test
-} // namespace search::btree
+} // namespace vespalib::btree::test
+} // namespace vespalib::btree